

%% Set the parameter values
%global theta_c;
theta_c = 129.73;

%global lambda;
lambda = 0.386;

%global theta_g;
theta_g = -21.38;


%global burnout;
burnout = 1000;


%global T;
T = 27*1000 + burnout;

%g_vec = [31.818; 12.7; 21.495; 31.494; 43.462; 51.616; 54.277]/10;
g_vec = linspace(12.7, 54.277, 22)'/10; %Divide by 10 to put into 10k lb units

%global J;
J = size(g_vec,1);
 
%global F;
F = 9;


f_names = {'Chrysler'; 'Ford' ;'Daimler'; 'GM'; 'Hino'; 'International'; 'Isuzu'; ...
    'Paccar'; 'Volvo'} ;

f_share = [5.56; 12.5; 12.5+4.17 + 1.39; 6.94; 4.17; 16.67; 6.94; 6.94+11.11; 2.78...
    + 4.17+4.17]/100; 




mu_f_vec = [repmat(100,F-1,1); 50];


%global avg_total_yearly_products;
avg_total_yearly_products = 48;

avg_products_per_firm = f_share * avg_total_yearly_products;

observed_9yr_totals = [8 + 21.3 + 8.3; 7.9 + 24.8 + 10.8; 8.3 + 27.1 + 9.6];
observed_threepd_variance = var( observed_9yr_totals);

markup = .35;
avg_price = mean( [64510, 68012, 67644]);
observed_variance_quantity = var( [467; 502; 494]/1000);%divide by 1000 to get in millions


%Create a table of the target market shares

%latex2( '%.2f', {'Firm', 'Target Market Share', 'Target Avg. Products'}, f_names, f_share, avg_products_per_firm)
%% Make covariate arrays

%Make arrays corresponding to the covariates for the products in the shocks
%arrays. Again, the arrays are F x J x T

F_array = repmat( (1:F)',1, J, T);
G_array = repmat( g_vec',F,1,T);





%% Draw the shocks


%The shocks will be stored in a three dimensional array of size F X J x T
% The first dimension (rows) will represent different firms, the second
% dimension (columns) will represent the different products, and the third
% dimension (depth) will represent different time periods

%I will take the draws of the shocks from standard normals. To go from
% Eta_shocks to the Eta_draws, I will multiply by sigma_eta. Likewise, to
% go from the Epsilon_shocks to the Epsilon_draws,  I will multiply by sigma_f
% and then add mu_f to each row. I start with the standard shocks so that
% we can use the same draws regardless of the parameters


Eta_jt_shocks_array = NaN(F,J,T);
Epsilon_shocks_array = NaN(F,J,T);
Zetaj_shocks_array = NaN(F,J,T);
Zetajft_shocks_array = NaN(F,J,T);

Eta_t_vec = zeros(T);


rng(0);
for t= 1:T
    %For eta, take one draw for each j for period t
    %Right now, assuming that the shocks are uncorrelated across J. Could
    %relax this (change away from eye(J) )
    eta_jt_shocks_t = mvnrnd( zeros(1,J), eye(J) ); 
    
    %Do the same for zeta_j
    zetaj_shocks_t = mvnrnd( zeros(1,J), eye(J) );
    
    %Create and store the eta draw matrix for period t.
    %The eta draw is the same for product j for each firm, so the eta_shocks
    %matrix for period t has constant columns (this is done in the repmat)
    Eta_jt_shocks_array(:,:,t) = repmat( eta_jt_shocks_t, F, 1);
   
    %Do the same for zeta_j
    Zetaj_shocks_array(:,:,t) = repmat( zetaj_shocks_t, F, 1);
    
    %Draw the epsilon_tfj. These are assumed to be independent across all
    %draws
    Epsilon_shocks_array(:,:,t) = randn(F,J);
    
    %Do the same for zeta_jft
    Zetajft_shocks_array(:,:,t) = randn(F,J);
   
end





%% Calibrate sigma_zeta to match variance in pi

sigma_nu = 30;
sigma_eps = 30;

 [mu_f, J_t, J_tm1, Pi_star_array] = mu_f_optimal( avg_products_per_firm, mu_f_vec, sigma_nu, ...
     sigma_eps, zeros(F,J) , Epsilon_shocks_array, Eta_jt_shocks_array, Eta_t_vec, G_array, burnout, T, F, J, theta_c, theta_g, lambda);

%This function returns the pi_star array as a function of sigma_z. It sets
%sigma_zetaj= sigma_zetajft, and uses the shocks and the pi_star already
%calculated
pi_star_sigma_fn = @(sigma_z) pi_array_fn( Pi_star_array, Zetaj_shocks_array, Zetajft_shocks_array, sigma_z, sigma_z);

%This function takes the 9-year variance of the sum of the pi-stars for the
%products that were in the market
pi_star_variance_fn = @(sigma_z) nineyr_variance( J_t .* pi_star_sigma_fn(sigma_z) , burnout )  ;

target_variance_pi = markup^2 * avg_price^2 * observed_variance_quantity;

%Variance if there were no sigma_z as a fraction of target (check that htis is < 1)
nineyr_variance( Pi_star_array .* J_t, burnout) / target_variance_pi

myopts = optimset('TolX', 10^(-6), 'TolFun', 10^(-6) );
sigma_zeta = fzero( @(sigma_z) pi_star_variance_fn(sigma_z) - target_variance_pi, [0,target_variance_pi])


%% Make tables of calibrated params

%latex2( '%.2f', {'Firm', '$\mu_f$'}, f_names, mu_f)
%latex2( '%.2f', {'Parameter', 'Value'}, {'$\sigma_\nu$' ; '$\sigma_\epsilon$';'$\sigma_\zeta$' }, [sigma_nu; sigma_eps; sigma_zeta ])

%Save the calibrated parameters
mkdir('../../Output/Simulated_Data/');
save('../../Output/Simulated_Data/calibrated_params', 'sigma_nu', 'sigma_eps', 'sigma_zeta', 'mu_f');

%% Simulate Data using Calibrated Parameters
% Now, we simulate one long chain

load('../../Output/Simulated_Data/calibrated_params');

%%

sigma_w =0;
sigma_zetaj = sigma_zeta;

sigma_zetajft = sigma_zeta;
rho = 0.9;


%Re-set T

T = 50000 + burnout;
 
mkdir('../../Output/Simulated_Data/Calibrated_SigmaZeta/');
save('../../Output/Simulated_Data/Calibrated_SigmaZeta/all_simulation_params',...
'F' , 'J' ,'T', 'burnout', 'sigma_nu', 'sigma_eps', 'sigma_w', 'sigma_zetaj',...
'sigma_zetajft', 'rho', 'lambda','theta_c','theta_g', 'g_vec', 'mu_f');

[J_t_array, J_tminus1_array, Pi_array, F_array, G_array, Pi_star_array, Eta_jt_shocks_array, Eta_t_vec] = simulate_data(1, F , J ,T, burnout, sigma_nu, sigma_eps, sigma_w, sigma_zetaj, sigma_zetajft, rho, lambda,theta_c,theta_g, g_vec, mu_f);
    
    % Save the desired values
        ds_name = '../../Output/Simulated_Data/Calibrated_SigmaZeta/ds_long';
        save( ds_name, 'J_t_array', 'J_tminus1_array', 'Pi_array', 'F_array', 'G_array', 'Pi_star_array', 'Eta_jt_shocks_array', 'Eta_t_vec', '-v7.3');

    
    

display('Simulation Complete.');
